package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/SIPUSH.class */
public class SIPUSH extends Instruction implements ConstantPushInstruction {
    private short b;

    /* JADX INFO: Access modifiers changed from: package-private */
    public SIPUSH() {
    }

    public SIPUSH(short b) {
        super((short) 17, (short) 3);
        this.b = b;
    }

    @Override // org.apache.bcel.generic.Instruction
    public void accept(Visitor v) {
        v.visitPushInstruction(this);
        v.visitStackProducer(this);
        v.visitTypedInstruction(this);
        v.visitConstantPushInstruction(this);
        v.visitSIPUSH(this);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        super.dump(out);
        out.writeShort(this.b);
    }

    @Override // org.apache.bcel.generic.TypedInstruction
    public Type getType(ConstantPoolGen cp) {
        return Type.SHORT;
    }

    @Override // org.apache.bcel.generic.ConstantPushInstruction
    public Number getValue() {
        return Integer.valueOf(this.b);
    }

    @Override // org.apache.bcel.generic.Instruction
    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        super.setLength(3);
        this.b = bytes.readShort();
    }

    @Override // org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        return super.toString(verbose) + " " + ((int) this.b);
    }
}
